AnyIO
=====

.. include:: ../README.rst

The manual
----------

.. toctree::
   :maxdepth: 2

   basics
   tasks
   cancellation
   synchronization
   threads
   fileio
   networking
   signals
   testing
   api
   versionhistory
